import Image from "next/image";
import { FC } from "react";
import Container from "components/Container";
import Link from "next/link";

interface HeaderProps {
  children: React.ReactNode;
  environment?: string;
}

const Header: FC<HeaderProps> = ({
  environment,
  children
}) => {
  return (
    <>
      <div className='text-center bg-white-transparent pt-6 mb-20'>
        <Container>
          <Link href='/'>
            <a>
              <div className='flex flex-col lg:flex-row items-center justify-center mb-5'>
                <Image objectFit='contain' width={230} height={120} src='/img/fim-uhk.png' alt='FIM UHK' />
                <div className='mx-10'>
                  <Image objectFit='contain' width={200} height={100} src='/img/logo-k8s.png' alt='Kubernetes' />
                </div>
                <Image objectFit='contain' width={200} height={70} src='/img/logo-nextjs.png' alt='Next.js' />
              </div>
            </a>
          </Link>
          {
            environment && (
              <div className='mb-4'>
                <span className='inline border-[2px] border-green text-green px-3 py-1 rounded-xl'>{environment}</span>
              </div>
            )
          }
          {children}
        </Container>
      </div>
    </>
  )
}

export default Header;