import { FC, useEffect, useState } from "react";
import Particles from "react-tsparticles";
import { loadFull } from "tsparticles";
import Container from "components/Container";


interface PrimaryProps {
  title?: string;
  children: React.ReactNode;
}

const Primary: FC<PrimaryProps> = ({
  title,
  children
}) => {

  const particlesInit = async (main: any) => {
    await loadFull(main);
  };

  const [
    particlesHidden,
    setParticlesHidden
  ] = useState(false);

  useEffect(() => {
    const onResize = () => {
      if (window.innerWidth > 3100) {
        setParticlesHidden(true);
      } else {
        setParticlesHidden(false);
      }
    }
    window.addEventListener("resize", onResize);
    return () => {
      window.removeEventListener("resize", onResize);
    };
  });

  return (
    <div className="h-full flex flex-col">
      <main className="flex-auto pb-16">
        <div className="w-[230px] relative z-[-1]">
          {
            !particlesHidden && (
              <Particles
                id="tsparticles"
                init={particlesInit}
                style={{position: "relative"}}
                options={{
                  background: {
                    color: {
                      value: "#fff",
                    },
                  },
                  fpsLimit: 120,
                  particles: {
                    color: {
                      value: "#009fdf",
                    },
                    links: {
                      color: "#009fdf",
                      distance: 150,
                      enable: true,
                      opacity: 0.2,
                      width: 1,
                    },
                    collisions: {
                      enable: true,
                    },
                    move: {
                      direction: "none",
                      enable: true,
                      outModes: {
                        default: "bounce",
                      },
                      random: false,
                      straight: false,
                    },
                    number: {
                      density: {
                        enable: true,
                        area: 800,
                      },
                      value: 100,
                    },
                    opacity: {
                      value: 0.2,
                    },
                    shape: {
                      type: "circle",
                    },
                    size: {
                      value: { min: 1, max: 5 },
                    },
                  },
                  detectRetina: true,
                }}
              />
            )
          }
        </div>
        {children}
      </main>

      <footer className="shrink-0 text-center bg-primary text-white py-8">
        <Container>
          <span>University Qualification Thesis 2022/23 &middot; Dominik Resl &middot; FIM UHK - Applied Informatics</span>
        </Container>
      </footer>
    </div>
  )
}

export default Primary;