import type { NextApiRequest, NextApiResponse } from 'next';
import axios from 'axios';
import * as https from 'https';

type Data = {
  data: Object
}

const b64_to_utf8 = (str: string) => {
  return Buffer.from(str, 'base64');
}

const cluster = {
  name: 'local-config',
  server: 'https://49.12.186.221:6443',
  cert: process.env.CLUSTER_CERT || ''
};

const user = {
  name: process.env.API_USER,
  token: process.env.API_USER_TOKEN
};

const httpsAgent = new https.Agent({
  rejectUnauthorized: false,
  cert: b64_to_utf8(cluster.cert)
});

const instance = axios.create({ httpsAgent });

const getK8sData = async(node: '01' | '02' | string = '01') => {
  const { data } = await instance.get(`${cluster.server}/api/v1/nodes/hetzner-eu-central-compute-${node}/proxy/stats/summary`, {
    headers: {
      "Authorization" : `Bearer ${user.token}`,
      'Access-Control-Allow-Origin': '*',
    }
  })
  return data;
}

const handler = async(
  req: NextApiRequest,
  res: NextApiResponse<Data>
) => {
  // @ts-ignore
  const { node } : { node: string } = req.query;
  const data = await getK8sData(node);
  res.status(200).json(data)
}

export default handler;
